@@ -9,9 +9,12 @@ import sys, os, os.path
 import errno
 import gettext 
 
-root_dir = os.path.dirname(__file__)
-if not os.path.exists(os.path.join(root_dir, 'Makefile.am')):
-    # Running in installed mode
+if (sys.modules.has_key('glchess') and
+    hasattr(sys.modules["glchess"],'installed_mode') and
+    sys.modules["glchess"].installed_mode):
+    # If the installed_mode attribute is not set, then we are
+    # importing from something other than the glchess script; we
+    # assume anyone importing in this way is doing testing etc.
     APP_DATA_DIR     = os.path.join('/usr/local', 'share') 
     ICON_DIR         = os.path.join(APP_DATA_DIR, 'pixmaps')
     TEXTURE_DIR      = os.path.join(ICON_DIR, 'glchess')
@@ -24,15 +27,12 @@ if not os.path.exists(os.path.join(root_dir, 'Makefile.am')):
     HISTORY_DIR      = os.path.join(DATA_DIR, 'history')
     UNFINISHED_FILE  = os.path.join(HISTORY_DIR, 'unfinished')
     LOCAL_AI_CONFIG  = os.path.join(DATA_DIR, 'ai.xml')
-    GGZ_DIR          = os.path.expanduser('~/.ggz')
-    GGZ_CONFIG_FILE  = os.path.join(GGZ_DIR, 'ggz-gtk.rc')
 else:
-    # Running in uninstalled mode
-    APP_DATA_DIR     = os.path.join(root_dir, '../../data')
-    ICON_DIR         = os.path.join(root_dir, '../../textures')
-    TEXTURE_DIR      = os.path.join(root_dir, '../../textures')
-    GLADE_DIR        = os.path.join(root_dir, '../../glade')
-    BASE_DIR         = os.path.join(root_dir, '../../data')
+    APP_DATA_DIR     = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'data')
+    ICON_DIR         = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'textures')
+    TEXTURE_DIR      = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'textures')
+    GLADE_DIR        = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'glade')
+    BASE_DIR         = os.path.join('/home/thomas/svn/gnome-games', 'glchess', 'data')
     LOCALEDIR        = os.path.join(APP_DATA_DIR, 'locale')
     DATA_DIR         = os.path.expanduser('~/.gnome2/glchess/')
     LOG_DIR          = os.path.join(DATA_DIR, 'logs')
@@ -50,7 +50,7 @@ import gtk.glade
 gtk.glade.bindtextdomain(DOMAIN, LOCALEDIR)
 gtk.glade.textdomain(DOMAIN)
 
-VERSION   = "2.22.3"
+VERSION   = "2.23.1"
 APPNAME   = _("glChess")
 ICON_NAME = 'gnome-glchess'
 
