@@ -487,23 +487,25 @@ gnibbles_move_worms ()
     status &= !dead[i];
   }
 
+  for (i = 0; i < properties->numworms; i++)
+    if (!dead[i] && worms[i]->lives > 0)
+      gnibbles_worm_move_tail (worms[i]);
+
+  for (i = 0; i < properties->numworms; i++)
+    if (!dead[i] && worms[i]->lives > 0)
+      gnibbles_worm_draw_head (worms[i]);
+
+
   /* If one worm has died, me must make sure that an earlier worm was not
    * supposed to die as well. */
 
-  if (!status)
-    for (i = 0; i < properties->numworms; i++)
-      if (!dead[i])
-	for (j = 0; j < properties->numworms; j++) {
-	  if (i != j
-	      && worms[i]->xhead == worms[j]->xhead
-	      && worms[i]->yhead == worms[j]->yhead)
-	    dead[i] = TRUE;
-	  gnibbles_draw_pixmap (BLANKPIXMAP,
-				worms[i]->xtail, worms[i]->ytail);
-	  gnibbles_draw_pixmap
-	    (properties->wormprops[i]->color,
-	     worms[i]->xhead, worms[i]->yhead);
-	}
+  for (i = 0; i < properties->numworms; i++)
+    for (j = 0; j < properties->numworms; j++) {
+      if (i != j
+          && worms[i]->xhead == worms[j]->xhead
+	  && worms[i]->yhead == worms[j]->yhead)
+	dead[i] = TRUE;
+    }
 
   for (i = 0; i < properties->numworms; i++)
     if (dead[i]) {
@@ -514,24 +516,17 @@ gnibbles_move_worms ()
         gnibbles_worm_reset (worms[i]);
         gnibbles_worm_set_start (worms[i],
 				 worms[i]->xstart,
-				 worms[i]->ystart, WORMDOWN);
-	gnibbles_play_sound ("crash");
-	return (CONTINUE);
+				 worms[i]->ystart,
+				 worms[i]->direction_start);
+	games_sound_play ("crash");
+	/* Don't return here.  May need to reset more worms. */
 	}
 
     }
 
-  for (i = 0; i < properties->numworms; i++)
-    if (worms[i]->lives)
-      gnibbles_worm_move_tail (worms[i]);
-
-  for (i = 0; i < properties->numworms; i++)
-    if (worms[i]->lives)
-      gnibbles_worm_draw_head (worms[i]);
-
   if (status & GAMEOVER) {
-    gnibbles_play_sound ("crash");
-    gnibbles_play_sound ("gameover");
+    games_sound_play ("crash");
+    games_sound_play ("gameover");
     return (GAMEOVER);
   }
 
@@ -589,13 +584,6 @@ gnibbles_undraw_worms (gint data)
     gnibbles_worm_undraw_nth (worms[i], data);
 }
 
-void
-gnibbles_play_sound (const char *which)
-{
-  if (properties->sound)
-    games_sound_play (which);
-}
-
 void
 gnibbles_show_scores (GtkWidget * window, gint pos)
 {
@@ -634,6 +622,9 @@ gnibbles_log_score (GtkWidget * window)
   if (properties->numworms > 1)
     return;
 
+  if (properties->human != 1)
+    return;
+
   if (properties->startlevel != 1)
     return;
 
